pub fn create_backend(
config: &BackendConfig,
) -> Result<DynTopologyGraph, BackendError>Expand description
Create a graph backend from configuration.
Errors
Returns an error if the backend cannot be created (e.g., SQLite file issues).
pub fn create_backend(
config: &BackendConfig,
) -> Result<DynTopologyGraph, BackendError>Create a graph backend from configuration.
Returns an error if the backend cannot be created (e.g., SQLite file issues).