run_benchmark

Function run_benchmark 

pub fn run_benchmark(
    colony: &mut Colony,
    config: &BenchmarkConfig,
) -> BenchmarkRun
Run a benchmark on a colony with the given configuration.

The colony should already have documents ingested and agents spawned. This function runs the simulation and collects data.