Corpus loader — replaces hard-coded documents in POC.
Provides a standard way to load text documents from a directory or use a built-in embedded test corpus. Every branch prototype uses this to ingest documents into the colony.
Structs
- Corpus
- A corpus of documents to be ingested into a colony.
- Corpus
Document - A single document in a corpus.